@@ -10,7 +10,7 @@ fn test_priority_get_from() -> Result<(), Error> {
     if let Err(err) = result {
         assert_eq!(err, ERR_ATTRIBUTE_NOT_FOUND.clone(), "unexpected error");
     } else {
-        assert!(false, "expected error, but got ok");
+        panic!("expected error, but got ok");
     }
 
     m.build(&[Box::new(BINDING_REQUEST), Box::new(p)])?;
@@ -26,13 +26,13 @@ fn test_priority_get_from() -> Result<(), Error> {
     //"IncorrectSize"
     {
         let mut m3 = Message::new();
-        m3.add(ATTR_PRIORITY, &vec![0; 100]);
+        m3.add(ATTR_PRIORITY, &[0; 100]);
         let mut p2 = PriorityAttr::default();
         let result = p2.get_from(&m3);
         if let Err(err) = result {
             assert!(is_attr_size_invalid(&err), "should error");
         } else {
-            assert!(false, "expected error, but got ok");
+            panic!("expected error, but got ok");
         }
     }
 
